PsPathPoint class final

A two-dimensional point in Photoshop path coordinates.

Constructors

PsPathPoint({required double x, required double y})
Creates a point from its horizontal and vertical components.
const
PsPathPoint.fromPixels({required double x, required double y, required int width, required int height})
Creates a normalized point from pixel coordinates and positive dimensions.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
Horizontal coordinate, normally relative to a reference width.
final
y double
Vertical coordinate, normally relative to a reference height.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pixelX(num width) double
Converts the horizontal component using width.
pixelY(num height) double
Converts the vertical component using height.
toString() String
A string representation of this object.
inherited
transform({double scaleX = 1, double scaleY = 1, double translateX = 0, double translateY = 0}) PsPathPoint
Applies an axis-aligned scale and translation to this point.

Operators

operator ==(Object other) bool
The equality operator.
inherited