PsReferenceClassValue class final

A class form inside a Photoshop object reference.

Inheritance
Available extensions

Constructors

PsReferenceClassValue({required String name, required String classId, bool compactClassId = true})
Creates a class-reference form.
const

Properties

classId String
Photoshop class identifier.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable class name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Four-character OSType stored before this value.
no setteroverride

Methods

asBoolean({PsDescriptorAccessMode mode = PsDescriptorAccessMode.strict}) bool?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as a Boolean.
asBytes() Uint8List?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as raw, alias, or path bytes.
asEnumeration({PsDescriptorAccessMode mode = PsDescriptorAccessMode.strict}) PsDescriptorEnumeration?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as an enumeration.
asInteger({PsDescriptorAccessMode mode = PsDescriptorAccessMode.strict}) int?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as an integer.
asList() List<PsDescriptorValue>?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as an ordered descriptor list.
asNumber() PsDescriptorNumber?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as a number with its optional unit.
asObject() PsDescriptor?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as a nested descriptor.
asObjectArray() PsObjectArrayValue?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as an object-array value.
asObjects() List<PsDescriptor>

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns nested descriptors from either one object or a list of objects.
asString({bool trimTerminalNulls = true}) String?

Available on PsDescriptorValue?, provided by the PsDescriptorValueAccess extension

Returns this value as text with optional terminal-null removal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited