PsFormatException class final
Reports malformed, truncated, or unsupported Photoshop-format input.
- Implemented types
Constructors
- PsFormatException({required String message, Object? source, int? offset})
-
Creates an error at an optional byte
offset.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable explanation of the malformed data.
final
- offset → int?
-
Absolute byte offset associated with the failure, when available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → Object?
-
Input object associated with the failure, when available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited